@@ -60,6 +60,7 @@ import org.glassfish.grizzly.http.server.Response;
 import org.glassfish.grizzly.http.util.MimeHeaders;
 import org.glassfish.grizzly.servlet.ServletUtils;
 import com.openexchange.java.Strings;
+import com.openexchange.servlet.StatusKnowing;
 
 /**
  * {@link HttpServletResponseWrapper} - Wraps an HttpServletResponse and delegates all calls that we don't need to modify to the response
@@ -67,11 +68,12 @@ import com.openexchange.java.Strings;
  *
  * @author <a href="mailto:marc.arens@open-xchange.com">Marc Arens</a>
  */
-public class HttpServletResponseWrapper implements HttpServletResponse {
+public class HttpServletResponseWrapper implements StatusKnowing {
 
     private final HttpServletResponse httpServletResponse;
     private final String echoHeaderName;
     private final String echoHeaderValue;
+    private int statusCode;
 
     /**
      * Initializes a new {@link HttpServletResponseWrapper}. Incorporates the echo header when using KippData's mod_id in case somebody
@@ -87,6 +89,11 @@ public class HttpServletResponseWrapper implements HttpServletResponse {
         this.echoHeaderValue = echoHeaderValue;
     }
 
+    @Override
+    public int getStatus() {
+        return statusCode;
+    }
+
     @Override
     public void addCookie(Cookie arg0) {
         httpServletResponse.addCookie(arg0);
@@ -262,11 +269,13 @@ public class HttpServletResponseWrapper implements HttpServletResponse {
 
     @Override
     public void setStatus(int arg0, String arg1) {
+        this.statusCode = arg0;
         httpServletResponse.setStatus(arg0, arg1);
     }
 
     @Override
     public void setStatus(int arg0) {
+        this.statusCode = arg0;
         httpServletResponse.setStatus(arg0);
     }
 
